%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Technical Note 172
% Parameters for 'Parallel operation of GFMIs' system
% Copyright imperix ltd, 2024
% dev@imperix.ch
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% SYSTEM PARAMETERS
SwitchingFreq = 50e3;           % Switching frequency [Hz]
ControlFreq = SwitchingFreq;    % Control frequency [Hz]
ControlPeriod = 1/ControlFreq;  % Control period [s]
SamplingPhase = 0;              % Sampling phase [-]

Vdc0 = 800;                     % Initial DC voltage [V]
Vg = 230;                       % RMS Grid voltage [V]
Freq = 50;                      % Grid frequency [Hz]
Lg = 0.95e-3;                   % TPI main inductor value [H]
Rg = 54e-3;                     % Series equivalent resistance of Lg [ohm]
Cf = 12.9e-6;                   % Capacitance of the filter [F]
Ll = 2.2e-3;                    % Transmission line inductance [H]

%% GRID CURRENT CONTROLLER PARAMETERS
% Optimum magnitude criterion
K1 = 1/Rg;
T1 = Lg/Rg;
Td1 = (1 + 1/2 + 1/2)*ControlPeriod;
Tn1 = T1;
Ti1 = 2*K1*Td1;
Kp_I = Tn1/Ti1;
Ki_I = 1/Ti1;
% Slow down the current control to reduce voltage drop when load changes
p = 5;
Kp_I = Kp_I/p;
Ki_I = Ki_I/p;

%% GRID VOLTAGE CONTROLLER PARAMETERS
% Symmetrical optimum criterion
T2 = Cf;
Tdeq = 10*Td1;
a = 2;
Ti2 = a^2*Tdeq;
Kp_V = T2/(a*Tdeq);
Ki_V = Kp_V/Ti2;

%% DROOP CONTROLLER PARAMETERS
% Proportional droop control
w0 = 2*pi*Freq;
delta_w_pu=1/100;
delta_w=delta_w_pu*w0;
P_max=16e3;
m=delta_w/P_max;
S_max=22e3;
delta_V_pu=10/100;
delta_V=230*sqrt(2)*delta_V_pu;
Q_max=sqrt(S_max^2-P_max^2);
n=delta_V/Q_max;
% Cutoff frequency of the filters
f_hpf_P = 0.1;
f_lpf_P = 0.3;
f_lpf_Q = 0.3;
